@@ -1,5 +1,9 @@
 ( cd opt/kde/share/doc/HTML/it/kdf ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kdf ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kig ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kig ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/juk ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/juk ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/ktuberling ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/ktuberling ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/amor ; rm -rf common )
@@ -10,14 +14,22 @@
 ( cd opt/kde/share/doc/HTML/it/kdvi ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kgeo ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kgeo ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kmag ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kmag ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kmid ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kmid ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kmix ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kmix ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kodo ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kodo ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kolf ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kolf ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kpat ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kpat ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/korn ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/korn ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/krec ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/krec ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kscd ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kscd ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/ksim ; rm -rf common )
@@ -28,8 +40,12 @@
 ( cd opt/kde/share/doc/HTML/it/kalzium ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/katomic ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/katomic ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/ksysguard ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/ksysguard ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kbounce ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kbounce ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kdearch ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kdearch ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kbattleship ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kbattleship ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kaboodle ; rm -rf common )
@@ -42,6 +58,8 @@
 ( cd opt/kde/share/doc/HTML/it/kpercentage ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcalc ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcalc ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kdesu ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kdesu ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcron ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcron ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kfind ; rm -rf common )
@@ -66,12 +84,16 @@
 ( cd opt/kde/share/doc/HTML/it/kwin4 ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/lskat ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/lskat ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kgoldrunner ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kgoldrunner ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcoloredit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcoloredit ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/klipper ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/klipper ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kvoctrain ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kvoctrain ; ln -sf /opt/kde/share/doc/HTML/it/common common )
-( cd opt/kde/share/doc/HTML/it/kmixcfg ; rm -rf common )
-( cd opt/kde/share/doc/HTML/it/kmixcfg ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kmousetool ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kmousetool ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/ksnapshot ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/ksnapshot ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kpackage ; rm -rf common )
@@ -100,10 +122,6 @@
 ( cd opt/kde/share/doc/HTML/it/flashkard ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kbackgammon ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kbackgammon ; ln -sf /opt/kde/share/doc/HTML/it/common common )
-( cd opt/kde/share/doc/HTML/it/kaddressbook ; rm -rf common )
-( cd opt/kde/share/doc/HTML/it/kaddressbook ; ln -sf /opt/kde/share/doc/HTML/it/common common )
-( cd opt/kde/share/doc/HTML/it/kxconfig ; rm -rf common )
-( cd opt/kde/share/doc/HTML/it/kxconfig ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/common ; rm -rf fdl-license )
 ( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/fdl-license fdl-license )
 ( cd opt/kde/share/doc/HTML/it/common ; rm -rf qpl-license.html )
@@ -140,6 +158,8 @@
 ( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/grad.png grad.png )
 ( cd opt/kde/share/doc/HTML/it/common ; rm -rf kde-web.css )
 ( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/kde-web.css kde-web.css )
+( cd opt/kde/share/doc/HTML/it/common ; rm -rf kde_logo_bg.png )
+( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/kde_logo_bg.png kde_logo_bg.png )
 ( cd opt/kde/share/doc/HTML/it/common ; rm -rf lgpl-license.html )
 ( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/lgpl-license.html lgpl-license.html )
 ( cd opt/kde/share/doc/HTML/it/common ; rm -rf doxygen.css )
@@ -154,12 +174,16 @@
 ( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/footer.html footer.html )
 ( cd opt/kde/share/doc/HTML/it/common ; rm -rf kde-common.css )
 ( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
+( cd opt/kde/share/doc/HTML/it/common ; rm -rf appheader.html )
+( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/appheader.html appheader.html )
 ( cd opt/kde/share/doc/HTML/it/common ; rm -rf doctop1.png )
 ( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/doctop1.png doctop1.png )
 ( cd opt/kde/share/doc/HTML/it/common ; rm -rf doctop2.png )
 ( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/doctop2.png doctop2.png )
 ( cd opt/kde/share/doc/HTML/it/common ; rm -rf shadow.png )
 ( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/shadow.png shadow.png )
+( cd opt/kde/share/doc/HTML/it/common ; rm -rf kde_logo.png )
+( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
 ( cd opt/kde/share/doc/HTML/it/common ; rm -rf docheadergears.png )
 ( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
 ( cd opt/kde/share/doc/HTML/it/common ; rm -rf fdl-license.html )
@@ -194,6 +218,8 @@
 ( cd opt/kde/share/doc/HTML/it/kcontrol/smb ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/spellchecking ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/spellchecking ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/bell ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/bell ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/powerctrl ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/powerctrl ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/kalarmd ; rm -rf common )
@@ -208,12 +234,20 @@
 ( cd opt/kde/share/doc/HTML/it/kcontrol/clock ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/email ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/email ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/mouse ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/mouse ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/proxy ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/proxy ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/kmixcfg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/kmixcfg ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/desktopbehavior ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/desktopbehavior ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/lanbrowser ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/lanbrowser ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/passwords ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/passwords ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/panelappearance ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/panelappearance ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/ebrowsing ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/ebrowsing ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/colors ; rm -rf common )
@@ -238,16 +272,22 @@
 ( cd opt/kde/share/doc/HTML/it/kamera ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kasteroids ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kasteroids ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kbruch ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kbruch ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/keduca ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/keduca ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kmessedwords ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kmessedwords ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kdevelop ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kdevelop ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kicker ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kicker ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/klines ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/klines ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kmines ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kmines ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kmouth ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kmouth ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kmplot ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kmplot ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/knotes ; rm -rf common )
@@ -266,10 +306,14 @@
 ( cd opt/kde/share/doc/HTML/it/ktimer ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/ktouch ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/ktouch ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kwrite ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kwrite ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/megami ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/megami ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kreversi ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kreversi ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/noatun ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/noatun ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kblackbox ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kblackbox ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcharselect ; rm -rf common )
@@ -282,8 +326,6 @@
 ( cd opt/kde/share/doc/HTML/it/klettres ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kfouleggs ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kfouleggs ; ln -sf /opt/kde/share/doc/HTML/it/common common )
-( cd opt/kde/share/doc/HTML/it/kaphorism ; rm -rf common )
-( cd opt/kde/share/doc/HTML/it/kaphorism ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kghostview ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kghostview ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/klickety ; rm -rf common )
@@ -336,5 +378,9 @@
 ( cd opt/kde/share/doc/HTML/it/kinfocenter/ioports ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kinfocenter/protocols ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kinfocenter/protocols ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/konqueror ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/konqueror ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/korganizer ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/korganizer ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/atlantik ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/atlantik ; ln -sf /opt/kde/share/doc/HTML/it/common common )
